# PyTrbNet

This is a Python package wrapping libtrbnet.so.
It allows accessing trbnet registers from Python.

The package comes with two additional features:

* XmlDb support. Allows to query registers by their
  name as specified in the corresponding xml file.
* PCASpy-based EPICS IOC providing TrbNet register
  status information to the EPICS detector control
  system.

### Resources

* [The TRB Website](http://trb.gsi.de)
* [TrbNet Manual](http://jspc29.x-matter.uni-frankfurt.de/docu/trbnetdocu.pdf)
